(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.3' *)

(***************************************************************************)
(*                                                                         *)
(*                                                                         *)
(*  Under the Wolfram FreeCDF terms of use, this file and its content are  *)
(*  bound by the Creative Commons BY-SA Attribution-ShareAlike license.    *)
(*                                                                         *)
(*        For additional information concerning CDF licensing, see:        *)
(*                                                                         *)
(*         www.wolfram.com/cdf/adopting-cdf/licensing-options.html         *)
(*                                                                         *)
(*                                                                         *)
(***************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1088,         20]
NotebookDataLength[    108309,       2205]
NotebookOptionsPosition[    107112,       2172]
NotebookOutlinePosition[    107564,       2192]
CellTagsIndexPosition[    107521,       2189]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["7 de septiembre de 2020", "Text",
 TextAlignment->Right,ExpressionUUID->"c0710cb8-7450-4d85-9f80-4b7a92e7df30"],

Cell[CellGroupData[{

Cell["Balanceo de sistemas de cuencas hidrol\[OAcute]gicas", "Title",ExpressionUUID->"4397d2aa-cd5f-4fae-8933-b446057acd75"],

Cell["\<\
El siguiente ejemplo sencillo ilustra la forma de balancear un sistema de \
cuencas hidrol\[OAcute]gicas.  Cada nodo del sistema es una cuenca hidrol\
\[OAcute]gica y el sistema se puede representar con un grafo, a partir del \
cual se pueden realizar m\[UAcute]ltiples operaciones matem\[AAcute]ticas.

Las demandas especificadas son balanceadas con la oferta propia de cada \
cuenca y el caudal que proviene de aguas arriba.  El caudal proveniente de \
aguas arriba nunca puede ser negativo, por lo que la soluci\[OAcute]n inicial \
debe revisarse.

Se utilizan los nombres de variables cercanos a los de la \
NOM-011-CONAGUA-2015.  En este caso la oferta engloba a Cp (escurrimiento \
virgen), R (retornos) e  Im(importaciones), mientras que la demanda engloba a \
los Uc (usos), Ex (exportaciones), Ev (evaporaci\[OAcute]n) y Av (cambios de \
volumen).\
\>", "Text",ExpressionUUID->"2f986ba0-073f-4e84-a480-c61c38fae621"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "\"\<Ar   oferta  demanda    Ab   Eq       Abrev    \>\"", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", "    ", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matr", "\[Transpose]"}], ".", 
           RowBox[{"(", 
            RowBox[{"inver", ".", 
             RowBox[{"(", " ", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"d1", ",", "d2", ",", "d3", ",", "0"}], "}"}], "-", 
               "of", "+", 
               RowBox[{"{", 
                RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], 
              " ", ")"}]}], "  ", ")"}]}], " ", "//", "MatrixForm"}], " ", 
         ",", "\"\< + \>\"", ",", " ", 
         RowBox[{"(*", "  ", 
          RowBox[{
          "vector", " ", "Ar", " ", "a", " ", "partir", " ", "de", " ", "Ab", 
           " ", "sin", " ", "elementos", " ", "negativos"}], "  ", "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"of", " ", "//", "MatrixForm"}], ",", "\"\< - \>\"", " ", 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"d1", ",", "d2", ",", "d3", ",", "0"}], "}"}], "//", 
          "MatrixForm"}], ",", "\"\< = \>\"", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"inver", ".", 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"d1", ",", "d2", ",", "d3", ",", "0"}], "}"}], "-", 
             "of", "+", 
             RowBox[{"{", 
              RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], " ",
             ")"}]}], " ", "//", "MatrixForm"}], " ", ",", "\"\<+\>\"", ",", 
         "  ", 
         RowBox[{"(*", "  ", 
          RowBox[{
          "vector", " ", "Ab", " ", "sin", " ", "elementos", " ", 
           "negativos"}], "  ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}], "//", 
          "MatrixForm"}], ",", "\"\<     \>\"", ",", " ", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"inver", ".", 
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"d1", ",", "d2", ",", "d3", ",", "0"}], "}"}], "-", 
              "of", "+", 
              RowBox[{"{", 
               RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], 
             " ", ")"}]}], "+", 
           RowBox[{"{", 
            RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], " ", "//",
           "MatrixForm"}]}], "    ", "}"}], "]"}], ",", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"LayeredGraphPlot", "[", 
       RowBox[{
        RowBox[{"{", "     ", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "2"}], ",", "  ", 
            RowBox[{"f2", "[", "1", "]"}]}], " ", "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "\[Rule]", "2"}], ",", 
            RowBox[{"f2", "[", "3", "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", "4"}], ",", 
            RowBox[{"f2", "[", "2", "]"}]}], "  ", "}"}]}], "   ", "}"}], " ",
         ",", "\[IndentingNewLine]", " ", 
        RowBox[{"VertexLabeling", "\[Rule]", "All"}], ",", 
        RowBox[{"EdgeLabeling", "\[Rule]", "All"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\"\<  \>\""}], "\[IndentingNewLine]", "}"}], 
    "]"}], ",", "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d1", ",", "1", ",", "\"\<demanda cuenca 1 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d2", ",", "3", ",", "\"\<demanda cuenca 2 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d3", ",", "2", ",", "\"\<demanda cuenca 3 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eq1", ",", "0", ",", "\"\<equilibrio nodo 1 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eq2", ",", "0", ",", "\"\<equilibrio nodo 2 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eq3", ",", "0", ",", "\"\<equilibrio nodo 3 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Initialization", " ", "\[RuleDelayed]", 
    RowBox[{"(", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"grafo1", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "\[Rule]", "2"}], ",", 
         RowBox[{"3", "\[Rule]", "2"}], ",", 
         RowBox[{"2", "\[Rule]", "4"}]}], "}"}]}], " ", ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "definici\[OAcute]n", " ", "del", " ", "grafo", " ", "mediante", " ", 
        "v\[EAcute]rtices"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"matr", "=", 
       RowBox[{"AdjacencyMatrix", "[", "  ", "grafo1", " ", "]"}]}], " ", ";",
       "  ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "matriz", " ", "de", " ", "adyacencia", " ", "del", " ", "grafo"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"inver", "=", 
       RowBox[{"Inverse", "[", "   ", 
        RowBox[{
         RowBox[{"matr", "\[Transpose]"}], "-", 
         RowBox[{"IdentityMatrix", "[", " ", "4", " ", "]"}]}], "  ", "]"}]}],
       ";", " ", 
      RowBox[{"(*", "  ", 
       RowBox[{
       "la", " ", "matriz", " ", "inver", " ", "multiplicada", " ", "por", 
        " ", "el", " ", "vector", " ", "de", " ", "demanda", " ", "menos", 
        " ", "oferta", " ", "da", " ", "el", " ", "vector", " ", "de", " ", 
        "valores", " ", "de", " ", "Ab"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"of", "=", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", "4", ",", "0"}], "}"}]}], ";", " ", 
      RowBox[{"(*", "  ", 
       RowBox[{
       "matriz", " ", "de", " ", "oferta", " ", "de", " ", "cada", " ", 
        "cuenca"}], "  ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f2", "[", " ", "n_", "]"}], ":=", 
       RowBox[{"Framed", "[", "   ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", "   ", 
           RowBox[{
            RowBox[{"inver", ".", 
             RowBox[{"(", " ", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"d1", ",", "d2", ",", "d3", ",", "0"}], "}"}], "-", 
               "of", "+", 
               RowBox[{"{", 
                RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], 
              " ", ")"}]}], "+", 
            RowBox[{"{", 
             RowBox[{"eq1", ",", "eq2", ",", "eq3", ",", "0"}], "}"}]}], " ", 
           ")"}], "[", 
          RowBox[{"[", "n", "]"}], "]"}], " ", ",", "   ", 
         RowBox[{"Background", "\[Rule]", "Yellow"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "28"}], ",", " ", 
         RowBox[{"Alignment", "\[Rule]", "Right"}], ",", 
         RowBox[{"RoundingRadius", "\[Rule]", "10"}]}], "   ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f3", "[", 
        RowBox[{"dem1_", ",", "dem2_", ",", "dem3_"}], "]"}], ":=", " ", 
       RowBox[{
        RowBox[{"matr", "\[Transpose]"}], ".", 
        RowBox[{"(", " ", 
         RowBox[{"inver", ".", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"dem1", ",", "dem2", ",", "dem3", ",", "0"}], "}"}], "-",
             "of"}], ")"}]}], "    ", ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f4", "[", 
        RowBox[{"dem1_", ",", "dem2_", ",", "dem3_", ",", "n_"}], "]"}], ":=", 
       RowBox[{"Framed", "[", "    ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"inver", ".", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "dem1"}], ",", 
              RowBox[{"-", "dem2"}], ",", 
              RowBox[{"-", "dem3"}], ",", "0"}], "}"}]}], ")"}], "[", 
          RowBox[{"[", "n", "]"}], "]"}], " ", ",", "   ", 
         RowBox[{"Background", "\[Rule]", "LightBlue"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "28"}], ",", " ", 
         RowBox[{"Alignment", "\[Rule]", "Right"}], ",", 
         RowBox[{"RoundingRadius", "\[Rule]", "10"}]}], "   ", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", "   ", 
       RowBox[{
       "sistema", " ", "un", " ", "poco", " ", "m\[AAcute]s", " ", 
        "complicado"}], "   ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"grafo2", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"1", "\[Rule]", "2"}], ",", 
         RowBox[{"3", "\[Rule]", "2"}], ",", 
         RowBox[{"4", "\[Rule]", "2"}], ",", 
         RowBox[{"2", "\[Rule]", "5"}], ",", 
         RowBox[{"5", "\[Rule]", "6"}]}], "}"}]}], " ", ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "definici\[OAcute]n", " ", "del", " ", "grafo", " ", "mediante", " ", 
        "v\[EAcute]rtices"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"matr2", "=", 
       RowBox[{"AdjacencyMatrix", "[", "  ", "grafo2", " ", "]"}]}], " ", ";",
       "  ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "matriz", " ", "de", " ", "adyacencia", " ", "del", " ", "grafo"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"inver2", "=", 
       RowBox[{"Inverse", "[", "   ", 
        RowBox[{
         RowBox[{"matr2", "\[Transpose]"}], "-", 
         RowBox[{"IdentityMatrix", "[", " ", "6", " ", "]"}]}], "  ", "]"}]}],
       ";", " ", 
      RowBox[{"(*", "  ", 
       RowBox[{
       "la", " ", "matriz", " ", "inver", " ", "multimplicada", " ", "por", 
        " ", "el", " ", "vector", " ", "de", " ", "demanda", " ", "menos", 
        " ", "oferta", " ", "da", " ", "el", " ", "vector", " ", "de", " ", 
        "valores", " ", "de", " ", "Ab"}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"of2", "=", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "0"}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f0", "[", 
        RowBox[{
        "dem1_", ",", "dem2_", ",", "dem3_", ",", "dem4_", ",", "dem5_"}], 
        "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"matr2", "\[Transpose]"}], ".", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Boole", "[", "  ", 
            RowBox[{"Positive", "[", "   ", 
             RowBox[{"inver2", ".", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{
                 "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", 
                  ",", "0"}], "}"}], "-", "of2"}], ")"}]}], " ", "]"}], "]"}],
            "*", 
           RowBox[{"inver2", ".", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", 
                ",", "0"}], "}"}], "-", "of2"}], ")"}]}]}], ")"}]}], "+", 
        "of2", "-", 
        RowBox[{"{", 
         RowBox[{
         "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", ",", 
          "0"}], "}"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f6", "[", 
        RowBox[{
        "dem1_", ",", "dem2_", ",", "dem3_", ",", "dem4_", ",", "dem5_", ",", 
         "e1_", ",", "e2_", ",", "e3_", ",", "e4_", ",", "e5_", ",", "n_"}], 
        "]"}], ":=", 
       RowBox[{"Framed", "[", "    ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", "  ", 
           RowBox[{
            RowBox[{"inver2", ".", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", 
                 ",", "0"}], "}"}], "-", "of2", "+", 
               RowBox[{"{", 
                RowBox[{
                "e1", ",", "e2", ",", "e3", ",", "e4", ",", "e5", ",", "0"}], 
                "}"}]}], "  ", ")"}]}], " ", "+", 
            RowBox[{"{", 
             RowBox[{
             "e1", ",", "e2", ",", "e3", ",", "e4", ",", "e5", ",", "0"}], 
             "}"}]}], ")"}], "[", 
          RowBox[{"[", "n", "]"}], "]"}], " ", ",", "   ", 
         RowBox[{"Background", "\[Rule]", "Yellow"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", "28"}], ",", " ", 
         RowBox[{"Alignment", "\[Rule]", "Right"}], ",", 
         RowBox[{"RoundingRadius", "\[Rule]", "10"}]}], "   ", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f7", "[", 
        RowBox[{
        "dem1_", ",", "dem2_", ",", "dem3_", ",", "dem4_", ",", "dem5_"}], 
        "]"}], ":=", " ", 
       RowBox[{
        RowBox[{"matr2", "\[Transpose]"}], ".", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Boole", "[", "  ", 
           RowBox[{"Positive", "[", "   ", 
            RowBox[{"inver2", ".", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", 
                 ",", "0"}], "}"}], "-", "of2"}], ")"}]}], " ", "]"}], "   ", 
           "]"}], "*", 
          RowBox[{"inver2", ".", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "dem1", ",", "dem2", ",", "dem3", ",", "dem4", ",", "dem5", ",",
                "0"}], "}"}], "-", "of2"}], ")"}]}]}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "\[IndentingNewLine]", ")"}]}]}], "  ", 
  "\[IndentingNewLine]", "]"}]], "Input",ExpressionUUID->"37fc8380-a03f-4982-\
ab8c-a96c66a4d3e1"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`d1$$ = 1, $CellContext`d2$$ = 
    3, $CellContext`d3$$ = 2, $CellContext`eq1$$ = 0, $CellContext`eq2$$ = 
    0, $CellContext`eq3$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"sin t\[IAcute]tulo\"", Typeset`specs$$ = {{{
       Hold[$CellContext`d1$$], 1, "demanda cuenca 1 = "}, 0, 5, 1}, {{
       Hold[$CellContext`d2$$], 3, "demanda cuenca 2 = "}, 0, 5, 1}, {{
       Hold[$CellContext`d3$$], 2, "demanda cuenca 3 = "}, 0, 5, 1}, {{
       Hold[$CellContext`eq1$$], 0, "equilibrio nodo 1 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eq2$$], 0, "equilibrio nodo 2 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eq3$$], 0, "equilibrio nodo 3 = "}, 0, -5, -1}}, 
    Typeset`size$$ = {329., {156.5, 162.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`d1$18403$$ = 0, $CellContext`d2$18404$$ = 
    0, $CellContext`d3$18405$$ = 0, $CellContext`eq1$18406$$ = 
    0, $CellContext`eq2$18407$$ = 0, $CellContext`eq3$18408$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`d1$$ = 1, $CellContext`d2$$ = 
        3, $CellContext`d3$$ = 2, $CellContext`eq1$$ = 0, $CellContext`eq2$$ = 
        0, $CellContext`eq3$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`d1$$, $CellContext`d1$18403$$, 0], 
        Hold[$CellContext`d2$$, $CellContext`d2$18404$$, 0], 
        Hold[$CellContext`d3$$, $CellContext`d3$18405$$, 0], 
        Hold[$CellContext`eq1$$, $CellContext`eq1$18406$$, 0], 
        Hold[$CellContext`eq2$$, $CellContext`eq2$18407$$, 0], 
        Hold[$CellContext`eq3$$, $CellContext`eq3$18408$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Column[{"Ar   oferta  demanda    Ab   Eq       Abrev    ", 
         Row[{
           MatrixForm[
            Dot[
             Transpose[$CellContext`matr], 
             
             Dot[$CellContext`inver, {$CellContext`d1$$, $CellContext`d2$$, \
$CellContext`d3$$, 
                0} - $CellContext`of + {$CellContext`eq1$$, \
$CellContext`eq2$$, $CellContext`eq3$$, 0}]]], " + ", 
           MatrixForm[$CellContext`of], " - ", 
           
           MatrixForm[{$CellContext`d1$$, $CellContext`d2$$, \
$CellContext`d3$$, 0}], " = ", 
           MatrixForm[
            
            Dot[$CellContext`inver, {$CellContext`d1$$, $CellContext`d2$$, \
$CellContext`d3$$, 
               0} - $CellContext`of + {$CellContext`eq1$$, \
$CellContext`eq2$$, $CellContext`eq3$$, 0}]], "+", 
           
           MatrixForm[{$CellContext`eq1$$, $CellContext`eq2$$, \
$CellContext`eq3$$, 0}], "     ", 
           MatrixForm[
           Dot[$CellContext`inver, {$CellContext`d1$$, $CellContext`d2$$, \
$CellContext`d3$$, 
                0} - $CellContext`of + {$CellContext`eq1$$, \
$CellContext`eq2$$, $CellContext`eq3$$, 
                0}] + {$CellContext`eq1$$, $CellContext`eq2$$, \
$CellContext`eq3$$, 0}]}], 
         LayeredGraphPlot[{{1 -> 2, 
            $CellContext`f2[1]}, {3 -> 2, 
            $CellContext`f2[3]}, {2 -> 4, 
            $CellContext`f2[2]}}, VertexLabeling -> All, EdgeLabeling -> All, 
          ImageSize -> Small], "  "}], 
      "Specifications" :> {{{$CellContext`d1$$, 1, "demanda cuenca 1 = "}, 0, 
         5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`d2$$, 3, "demanda cuenca 2 = "}, 0, 5, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`d3$$, 2, "demanda cuenca 3 = "}, 0, 5, 1, 
         Appearance -> 
         "Labeled"}, {{$CellContext`eq1$$, 0, "equilibrio nodo 1 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eq2$$, 0, "equilibrio nodo 2 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eq3$$, 0, "equilibrio nodo 3 = "}, 
         0, -5, -1, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{406., {274., 280.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(($CellContext`grafo1 = {
        1 -> 2, 3 -> 2, 2 -> 4}; $CellContext`matr = 
       AdjacencyMatrix[$CellContext`grafo1]; $CellContext`inver = 
       Inverse[Transpose[$CellContext`matr] - IdentityMatrix[
         4]]; $CellContext`of = {2, 1, 4, 0}; $CellContext`f2[
         Pattern[$CellContext`n$, 
          Blank[]]] := Framed[
         Part[
         Dot[$CellContext`inver, {$CellContext`d1$$, $CellContext`d2$$, \
$CellContext`d3$$, 
              0} - $CellContext`of + {$CellContext`eq1$$, $CellContext`eq2$$, \
$CellContext`eq3$$, 
              0}] + {$CellContext`eq1$$, $CellContext`eq2$$, \
$CellContext`eq3$$, 0}, $CellContext`n$], Background -> Yellow, ImageSize -> 
         28, Alignment -> Right, RoundingRadius -> 10]; $CellContext`f3[
         Pattern[$CellContext`dem1, 
          Blank[]], 
         Pattern[$CellContext`dem2, 
          Blank[]], 
         Pattern[$CellContext`dem3, 
          Blank[]]] := Dot[
         Transpose[$CellContext`matr], 
         Dot[$CellContext`inver, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, 0} - $CellContext`of]]; $CellContext`f4[
         Pattern[$CellContext`dem1, 
          Blank[]], 
         Pattern[$CellContext`dem2, 
          Blank[]], 
         Pattern[$CellContext`dem3, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := Framed[
         Part[
          
          Dot[$CellContext`inver, {-$CellContext`dem1, -$CellContext`dem2, \
-$CellContext`dem3, 0}], $CellContext`n], Background -> LightBlue, ImageSize -> 
         28, Alignment -> Right, RoundingRadius -> 
         10]; $CellContext`grafo2 = {
        1 -> 2, 3 -> 2, 4 -> 2, 2 -> 5, 5 -> 6}; $CellContext`matr2 = 
       AdjacencyMatrix[$CellContext`grafo2]; $CellContext`inver2 = 
       Inverse[Transpose[$CellContext`matr2] - IdentityMatrix[
         6]]; $CellContext`of2 = {2, 2, 2, 2, 2, 0}; $CellContext`f0[
         Pattern[$CellContext`dem1, 
          Blank[]], 
         Pattern[$CellContext`dem2, 
          Blank[]], 
         Pattern[$CellContext`dem3, 
          Blank[]], 
         Pattern[$CellContext`dem4, 
          Blank[]], 
         Pattern[$CellContext`dem5, 
          Blank[]]] := Dot[
          Transpose[$CellContext`matr2], Boole[
            Positive[
             
             Dot[$CellContext`inver2, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, $CellContext`dem4, $CellContext`dem5, 
                0} - $CellContext`of2]]] 
          Dot[$CellContext`inver2, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, $CellContext`dem4, $CellContext`dem5, 
              0} - $CellContext`of2]] + $CellContext`of2 - \
{$CellContext`dem1, $CellContext`dem2, $CellContext`dem3, $CellContext`dem4, \
$CellContext`dem5, 0}; $CellContext`f6[
         Pattern[$CellContext`dem1, 
          Blank[]], 
         Pattern[$CellContext`dem2, 
          Blank[]], 
         Pattern[$CellContext`dem3, 
          Blank[]], 
         Pattern[$CellContext`dem4, 
          Blank[]], 
         Pattern[$CellContext`dem5, 
          Blank[]], 
         Pattern[$CellContext`e1, 
          Blank[]], 
         Pattern[$CellContext`e2, 
          Blank[]], 
         Pattern[$CellContext`e3, 
          Blank[]], 
         Pattern[$CellContext`e4, 
          Blank[]], 
         Pattern[$CellContext`e5, 
          Blank[]], 
         Pattern[$CellContext`n, 
          Blank[]]] := Framed[
         Part[
         Dot[$CellContext`inver2, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, $CellContext`dem4, $CellContext`dem5, 
              0} - $CellContext`of2 + {$CellContext`e1, $CellContext`e2, \
$CellContext`e3, $CellContext`e4, $CellContext`e5, 
              0}] + {$CellContext`e1, $CellContext`e2, $CellContext`e3, \
$CellContext`e4, $CellContext`e5, 0}, $CellContext`n], Background -> Yellow, 
         ImageSize -> 28, Alignment -> Right, RoundingRadius -> 
         10]; $CellContext`f7[
         Pattern[$CellContext`dem1, 
          Blank[]], 
         Pattern[$CellContext`dem2, 
          Blank[]], 
         Pattern[$CellContext`dem3, 
          Blank[]], 
         Pattern[$CellContext`dem4, 
          Blank[]], 
         Pattern[$CellContext`dem5, 
          Blank[]]] := Dot[
         Transpose[$CellContext`matr2], Boole[
           Positive[
            
            Dot[$CellContext`inver2, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, $CellContext`dem4, $CellContext`dem5, 
               0} - $CellContext`of2]]] 
         Dot[$CellContext`inver2, {$CellContext`dem1, $CellContext`dem2, \
$CellContext`dem3, $CellContext`dem4, $CellContext`dem5, 
             0} - $CellContext`of2]]); Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",ExpressionUUID->"1caa8ee1-\
8a5a-4e6f-90b8-ff4bc32a07fa"]
}, {2}]],

Cell[TextData[{
 "La matriz de adyacencia del sistema es:  ",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "1", "0", "0"},
      {"0", "0", "0", "1"},
      {"0", "1", "0", "0"},
      {"0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[
    SparseArray[
     Automatic, {4, 4}, 0, {
      1, {{0, 1, 2, 3, 3}, {{2}, {4}, {2}}}, {1, 1, 1}}]]]]],
  CellChangeTimes->{{3.798593404295431*^9, 3.798593412953926*^9}},
  ExpressionUUID->"29ae4d5c-a982-4b5e-918f-438ff088ab88"],
 "       Esta matriz muestra la configuraci\[OAcute]n o geometr\[IAcute]a del \
sistema.\nLa matriz de adyacencia transpuesta y multiplicada por el vector de \
flujos hacia abajo [Ab] da como resultado el vector de flujos que llegan a \
cada cuenca, el vector [Ar]\n[Ar]=[Ady]\[Transpose][Ab]\n\n[Ar] + [of] - \
[dem] = [Ab],  donde el vector [of] es el vector de oferta en cada cuenca y \
el vector [dem] es el vector de demanda en cada cuenca.\n\n\
[Ady]\[Transpose][Ab] + [of]-[dem] - [Ab] = [0], donde [0] es un vector con \
elementos 0.\nEsto se puede reescribir como   ( [Ady]\[Transpose] - [I] \
).[Ab] = [dem]-[of]\n[Ab] =  Inversa[  ( [Ady]\[Transpose] - [I] ) ].( \
[dem]-[of] )\n\nSin embargo, debe garantizarse que todos los elementos del \
vector [Ar] sean positivos, por lo que es necesario recalcular [Ar] con un \
[Ab] que no tenga valores negativos.\nPara lograr esto se utiliza el vector \
equilibrador [Eq] con el que los valores negativos del vector [Ab] se \
equilibran para convertirse en ceros."
}], "Text",ExpressionUUID->"15699757-4761-48f6-8c20-b0660e9f25f7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Escurrimiento Medio Anual (EMA)", "Title",ExpressionUUID->"b58dab2d-66d0-4fec-8ee9-fdd7121b0244"],

Cell["\<\
Con operaciones similares se puede obtener el Escurrimiento Medio Anual en \
diferentes puntos del sistema de cuencas.  Este ejemplo es muy sencillo, pero \
la metodolog\[IAcute]a es aplicable a cualquier tama\[NTilde]o de sistema, \
como se muestra m\[AAcute]s abajo.\
\>", "Text",ExpressionUUID->"ac6b517c-1936-4614-a839-2116c6c60cce"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"LayeredGraphPlot", "[", 
       RowBox[{
        RowBox[{"{", "     ", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "2"}], ",", "  ", 
            RowBox[{"f4", "[", 
             RowBox[{"c1", ",", "c2", ",", "c3", ",", "1"}], "]"}]}], " ", 
           "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "\[Rule]", "2"}], ",", 
            RowBox[{"f4", "[", 
             RowBox[{"c1", ",", "c2", ",", "c3", ",", "3"}], "]"}]}], "}"}], 
          ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", "4"}], ",", 
            RowBox[{"f4", "[", 
             RowBox[{"c1", ",", "c2", ",", "c3", ",", "2"}], "]"}]}], "  ", 
           "}"}]}], "   ", "}"}], " ", ",", " ", 
        RowBox[{"VertexLabeling", "\[Rule]", "All"}], ",", 
        RowBox[{"EdgeLabeling", "\[Rule]", "All"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Small"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\"\<  \>\""}], "\[IndentingNewLine]", "}"}], 
    "]"}], ",", "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c1", ",", "1", ",", "\"\<escurrimiento virgen cuenca 1 = \>\""}], 
      "}"}], ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c2", ",", "3", ",", "\"\<escurrimiento virgen cuenca 2 = \>\""}], 
      "}"}], ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "c3", ",", "2", ",", "\"\<escurrimiento virgen cuenca 3 = \>\""}], 
      "}"}], ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",ExpressionUUID->"a07988e0-7b63-454e-\
8051-79d139e41ec8"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`c1$$ = 1, $CellContext`c2$$ = 
    3, $CellContext`c3$$ = 2, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"sin t\[IAcute]tulo\"", Typeset`specs$$ = {{{
       Hold[$CellContext`c1$$], 1, "escurrimiento virgen cuenca 1 = "}, 0, 5, 
      1}, {{
       Hold[$CellContext`c2$$], 3, "escurrimiento virgen cuenca 2 = "}, 0, 5, 
      1}, {{
       Hold[$CellContext`c3$$], 2, "escurrimiento virgen cuenca 3 = "}, 0, 5, 
      1}}, Typeset`size$$ = {109., {113.5, 119.5}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`c1$11174$$ = 0, $CellContext`c2$11175$$ = 
    0, $CellContext`c3$11176$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`c1$$ = 1, $CellContext`c2$$ = 
        3, $CellContext`c3$$ = 2}, "ControllerVariables" :> {
        Hold[$CellContext`c1$$, $CellContext`c1$11174$$, 0], 
        Hold[$CellContext`c2$$, $CellContext`c2$11175$$, 0], 
        Hold[$CellContext`c3$$, $CellContext`c3$11176$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Column[{
         LayeredGraphPlot[{{1 -> 2, 
            $CellContext`f4[$CellContext`c1$$, $CellContext`c2$$, \
$CellContext`c3$$, 1]}, {3 -> 2, 
            $CellContext`f4[$CellContext`c1$$, $CellContext`c2$$, \
$CellContext`c3$$, 3]}, {2 -> 4, 
            $CellContext`f4[$CellContext`c1$$, $CellContext`c2$$, \
$CellContext`c3$$, 2]}}, VertexLabeling -> All, EdgeLabeling -> All, 
          ImageSize -> Small], "  "}], 
      "Specifications" :> {{{$CellContext`c1$$, 1, 
          "escurrimiento virgen cuenca 1 = "}, 0, 5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c2$$, 3, 
          "escurrimiento virgen cuenca 2 = "}, 0, 5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`c3$$, 2, 
          "escurrimiento virgen cuenca 3 = "}, 0, 5, 1, Appearance -> 
         "Labeled"}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{463., {189., 195.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",ExpressionUUID->"c0c17efe-\
6f09-4f29-8391-666b7bc1aa42"]
}, {2}]],

Cell[TextData[{
 "La ecuaci\[OAcute]n b\[AAcute]sica de equilibrio es [Ar]+[Cp]-[Ab]=[0],  \
pero [Ar]=[Ady]\[Transpose].[Ab], por lo que [Ab] = Inversa[  ([Ady]\
\[Transpose] - [ I ] ).[Cp].  Los valores del vector [Ab] son los valores del \
vector de escurrimientos medios anuales (EMA) buscados.\nLa matriz inversa \
para la geometr\[IAcute]a del sistema del ejemplo es:  ",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"-", "1"}], "0", "0", "0"},
      {
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], "0"},
      {"0", "0", 
       RowBox[{"-", "1"}], "0"},
      {
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]],
  CellChangeTimes->{{3.7986331982004642`*^9, 3.798633221600505*^9}, 
    3.7986332590405707`*^9},ExpressionUUID->
  "081ea7d7-dbb2-481d-a9f6-eb894238f674"],
 ", por lo que el vector de EMA es simplemente  ",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"-", "1"}], "0", "0", "0"},
      {
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], "0"},
      {"0", "0", 
       RowBox[{"-", "1"}], "0"},
      {
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]],
  CellChangeTimes->{{3.7986331982004642`*^9, 3.798633221600505*^9}, 
    3.7986332590405707`*^9},ExpressionUUID->
  "ac9005c8-052f-451c-931a-8dcc2faf002d"],
 ".",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", 
    TagBox[GridBox[{
       {"cp1"},
       {"cp2"},
       {"cp3"},
       {"0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.5599999999999999]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     Column], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]],
  CellChangeTimes->{3.7986333148896694`*^9},ExpressionUUID->
  "a31fbaab-7491-4356-9f84-047d5d0ed905"],
 ", donde el vector [Cp] tiene los escurrimientos v\[IAcute]rgenes (cp) en \
cada cuenca."
}], "Text",ExpressionUUID->"94e9c821-ff36-45fc-a30b-7fb021310699"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Un sistema un poco m\[AAcute]s complejo", "Title",ExpressionUUID->"f654fa73-153b-44be-bdcd-62c4acdeca4d"],

Cell["\<\
El siguiente ejemplo es un poco m\[AAcute]s complejo, pero aplican las mismas \
ecuaciones.  En este caso la matriz de adyacencia, y las dem\[AAcute]s \
matrices que se derivan, son de dimensiones 6 x 6. \
\>", "Text",ExpressionUUID->"6b80a2b1-8ea5-477f-8a29-2ee38cc67682"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Column", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "\"\< Ar   oferta  demanda    Ab     Eq       Abrev      \>\"", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", "    ", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"matr2", "\[Transpose]"}], ".", 
           RowBox[{"(", 
            RowBox[{"inver2", ".", 
             RowBox[{"(", " ", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
                 "0"}], "}"}], "-", "of2", "+", 
               RowBox[{"{", 
                RowBox[{
                "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", 
                 ",", "0"}], "}"}]}], " ", ")"}]}], "  ", ")"}]}], " ", "//", 
          "MatrixForm"}], " ", ",", "\"\< + \>\"", ",", "\[IndentingNewLine]", 
         RowBox[{"of2", " ", "//", "MatrixForm"}], ",", "\"\< - \>\"", " ", 
         ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", "0"}], 
           "}"}], "//", "MatrixForm"}], ",", "\"\< = \>\"", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"inver2", ".", 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
              "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
               "0"}], "}"}], "-", "of2", "+", 
             RowBox[{"{", 
              RowBox[{
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
                "0"}], "}"}]}], " ", ")"}]}], "//", "MatrixForm"}], "    ", 
         ",", "\"\< + \>\"", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
           "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",", 
            "0"}], "}"}], " ", "//", "MatrixForm"}], ",", "\"\<    \>\"", ",",
          "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"inver2", ".", 
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
               "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
                "0"}], "}"}], "-", "of2", "+", 
              RowBox[{"{", 
               RowBox[{
               "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", 
                ",", "0"}], "}"}]}], " ", ")"}]}], "+", 
           RowBox[{"{", 
            RowBox[{
            "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",", 
             "0"}], "}"}]}], "//", "MatrixForm"}]}], "   ", "}"}], "]"}], ",",
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"LayeredGraphPlot", "[", 
       RowBox[{
        RowBox[{"{", "     ", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1", "\[Rule]", "2"}], ",", "  ", 
            RowBox[{"f6", "[", 
             RowBox[{
             "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
               "1"}], "]"}]}], " ", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"3", "\[Rule]", "2"}], ",", 
            RowBox[{"f6", "[", 
             RowBox[{
             "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
               "3"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"4", "\[Rule]", "2"}], ",", 
            RowBox[{"f6", "[", 
             RowBox[{
             "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
               "4"}], "]"}]}], "  ", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"2", "\[Rule]", "5"}], ",", 
            RowBox[{"f6", "[", 
             RowBox[{
             "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
               "2"}], "]"}]}], "  ", "}"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"5", "\[Rule]", "6"}], ",", 
            RowBox[{"f6", "[", 
             RowBox[{
             "dd1", ",", "dd2", ",", "dd3", ",", "dd4", ",", "dd5", ",", 
              "eqq1", ",", "eqq2", ",", "eqq3", ",", "eqq4", ",", "eqq5", ",",
               "5"}], "]"}]}], "  ", "}"}]}], "   ", "}"}], " ", ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"VertexLabeling", "\[Rule]", "All"}], ",", 
        RowBox[{"EdgeLabeling", "\[Rule]", "All"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", "Medium"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd1", ",", "1", ",", "\"\<demanda cuenca 1 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd2", ",", "3", ",", "\"\<demanda cuenca 2 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd3", ",", "1", ",", "\"\<demanda cuenca 3 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd4", ",", "3", ",", "\"\<demanda cuenca 4 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"dd5", ",", "2", ",", "\"\<demanda cuenca 5 = \>\""}], "}"}], 
     ",", "0", ",", "5", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqq1", ",", "0", ",", "\"\<equilibrio nodo 1 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqq2", ",", "0", ",", "\"\<equilibrio nodo 2 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqq3", ",", "0", ",", "\"\<equilibrio nodo 3 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqq4", ",", "0", ",", "\"\<equilibrio nodo 4 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"eqq5", ",", "0", ",", "\"\<equilibrio nodo 5 = \>\""}], "}"}], 
     ",", "0", ",", 
     RowBox[{"-", "5"}], ",", 
     RowBox[{"-", "1"}], ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]], "Input",ExpressionUUID\
->"6f0035d2-bf34-4268-861e-7142f0a5133b"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`dd1$$ = 1, $CellContext`dd2$$ = 
    3, $CellContext`dd3$$ = 1, $CellContext`dd4$$ = 3, $CellContext`dd5$$ = 
    2, $CellContext`eqq1$$ = 0, $CellContext`eqq2$$ = 0, $CellContext`eqq3$$ =
     0, $CellContext`eqq4$$ = -1, $CellContext`eqq5$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"sin t\[IAcute]tulo\"", Typeset`specs$$ = {{{
       Hold[$CellContext`dd1$$], 1, "demanda cuenca 1 = "}, 0, 5, 1}, {{
       Hold[$CellContext`dd2$$], 3, "demanda cuenca 2 = "}, 0, 5, 1}, {{
       Hold[$CellContext`dd3$$], 1, "demanda cuenca 3 = "}, 0, 5, 1}, {{
       Hold[$CellContext`dd4$$], 3, "demanda cuenca 4 = "}, 0, 5, 1}, {{
       Hold[$CellContext`dd5$$], 2, "demanda cuenca 5 = "}, 0, 5, 1}, {{
       Hold[$CellContext`eqq1$$], 0, "equilibrio nodo 1 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eqq2$$], 0, "equilibrio nodo 2 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eqq3$$], 0, "equilibrio nodo 3 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eqq4$$], 0, "equilibrio nodo 4 = "}, 0, -5, -1}, {{
       Hold[$CellContext`eqq5$$], 0, "equilibrio nodo 5 = "}, 0, -5, -1}}, 
    Typeset`size$$ = {364., {273., 279.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`dd1$19811$$ = 0, $CellContext`dd2$19812$$ = 
    0, $CellContext`dd3$19813$$ = 0, $CellContext`dd4$19814$$ = 
    0, $CellContext`dd5$19815$$ = 0, $CellContext`eqq1$19816$$ = 
    0, $CellContext`eqq2$19817$$ = 0, $CellContext`eqq3$19818$$ = 
    0, $CellContext`eqq4$19819$$ = 0, $CellContext`eqq5$19820$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`dd1$$ = 1, $CellContext`dd2$$ = 
        3, $CellContext`dd3$$ = 1, $CellContext`dd4$$ = 3, $CellContext`dd5$$ = 
        2, $CellContext`eqq1$$ = 0, $CellContext`eqq2$$ = 
        0, $CellContext`eqq3$$ = 0, $CellContext`eqq4$$ = 
        0, $CellContext`eqq5$$ = 0}, "ControllerVariables" :> {
        Hold[$CellContext`dd1$$, $CellContext`dd1$19811$$, 0], 
        Hold[$CellContext`dd2$$, $CellContext`dd2$19812$$, 0], 
        Hold[$CellContext`dd3$$, $CellContext`dd3$19813$$, 0], 
        Hold[$CellContext`dd4$$, $CellContext`dd4$19814$$, 0], 
        Hold[$CellContext`dd5$$, $CellContext`dd5$19815$$, 0], 
        Hold[$CellContext`eqq1$$, $CellContext`eqq1$19816$$, 0], 
        Hold[$CellContext`eqq2$$, $CellContext`eqq2$19817$$, 0], 
        Hold[$CellContext`eqq3$$, $CellContext`eqq3$19818$$, 0], 
        Hold[$CellContext`eqq4$$, $CellContext`eqq4$19819$$, 0], 
        Hold[$CellContext`eqq5$$, $CellContext`eqq5$19820$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Column[{" Ar   oferta  demanda    Ab     Eq       Abrev      ", 
         Row[{
           MatrixForm[
            Dot[
             Transpose[$CellContext`matr2], 
             
             Dot[$CellContext`inver2, {$CellContext`dd1$$, \
$CellContext`dd2$$, $CellContext`dd3$$, $CellContext`dd4$$, \
$CellContext`dd5$$, 
                0} - $CellContext`of2 + {$CellContext`eqq1$$, \
$CellContext`eqq2$$, $CellContext`eqq3$$, $CellContext`eqq4$$, \
$CellContext`eqq5$$, 0}]]], " + ", 
           MatrixForm[$CellContext`of2], " - ", 
           
           MatrixForm[{$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, 0}], " = ", 
           MatrixForm[
            
            Dot[$CellContext`inver2, {$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, 
               
               0} - $CellContext`of2 + {$CellContext`eqq1$$, \
$CellContext`eqq2$$, $CellContext`eqq3$$, $CellContext`eqq4$$, \
$CellContext`eqq5$$, 0}]], " + ", 
           
           MatrixForm[{$CellContext`eqq1$$, $CellContext`eqq2$$, \
$CellContext`eqq3$$, $CellContext`eqq4$$, $CellContext`eqq5$$, 0}], "    ", 
           MatrixForm[
           Dot[$CellContext`inver2, {$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, 
                0} - $CellContext`of2 + {$CellContext`eqq1$$, \
$CellContext`eqq2$$, $CellContext`eqq3$$, $CellContext`eqq4$$, \
$CellContext`eqq5$$, 
                0}] + {$CellContext`eqq1$$, $CellContext`eqq2$$, \
$CellContext`eqq3$$, $CellContext`eqq4$$, $CellContext`eqq5$$, 0}]}], 
         LayeredGraphPlot[{{1 -> 2, 
            $CellContext`f6[$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, \
$CellContext`eqq1$$, $CellContext`eqq2$$, $CellContext`eqq3$$, \
$CellContext`eqq4$$, $CellContext`eqq5$$, 1]}, {3 -> 2, 
            $CellContext`f6[$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, \
$CellContext`eqq1$$, $CellContext`eqq2$$, $CellContext`eqq3$$, \
$CellContext`eqq4$$, $CellContext`eqq5$$, 3]}, {4 -> 2, 
            $CellContext`f6[$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, \
$CellContext`eqq1$$, $CellContext`eqq2$$, $CellContext`eqq3$$, \
$CellContext`eqq4$$, $CellContext`eqq5$$, 4]}, {2 -> 5, 
            $CellContext`f6[$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, \
$CellContext`eqq1$$, $CellContext`eqq2$$, $CellContext`eqq3$$, \
$CellContext`eqq4$$, $CellContext`eqq5$$, 2]}, {5 -> 6, 
            $CellContext`f6[$CellContext`dd1$$, $CellContext`dd2$$, \
$CellContext`dd3$$, $CellContext`dd4$$, $CellContext`dd5$$, \
$CellContext`eqq1$$, $CellContext`eqq2$$, $CellContext`eqq3$$, \
$CellContext`eqq4$$, $CellContext`eqq5$$, 5]}}, VertexLabeling -> All, 
          EdgeLabeling -> All, ImageSize -> Medium]}], 
      "Specifications" :> {{{$CellContext`dd1$$, 1, "demanda cuenca 1 = "}, 0,
          5, 1, Appearance -> 
         "Labeled"}, {{$CellContext`dd2$$, 3, "demanda cuenca 2 = "}, 0, 5, 1,
          Appearance -> 
         "Labeled"}, {{$CellContext`dd3$$, 1, "demanda cuenca 3 = "}, 0, 5, 1,
          Appearance -> 
         "Labeled"}, {{$CellContext`dd4$$, 3, "demanda cuenca 4 = "}, 0, 5, 1,
          Appearance -> 
         "Labeled"}, {{$CellContext`dd5$$, 2, "demanda cuenca 5 = "}, 0, 5, 1,
          Appearance -> 
         "Labeled"}, {{$CellContext`eqq1$$, 0, "equilibrio nodo 1 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eqq2$$, 0, "equilibrio nodo 2 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eqq3$$, 0, "equilibrio nodo 3 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eqq4$$, 0, "equilibrio nodo 4 = "}, 
         0, -5, -1, Appearance -> 
         "Labeled"}, {{$CellContext`eqq5$$, 0, "equilibrio nodo 5 = "}, 
         0, -5, -1, Appearance -> "Labeled"}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{792., {305., 311.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",ExpressionUUID->"9cf49882-\
6678-49c9-9992-5bed5172f2e1"]
}, {2}]],

Cell[TextData[{
 "La matriz de adyacencia del \[UAcute]ltimo sistema es:  ",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", "1", "0", "0", "0", "0"},
      {"0", "0", "0", "1", "0", "0"},
      {"0", "1", "0", "0", "0", "0"},
      {"0", "0", "0", "0", "0", "1"},
      {"0", "0", "0", "1", "0", "0"},
      {"0", "0", "0", "0", "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[
    SparseArray[
     Automatic, {6, 6}, 0, {
      1, {{0, 1, 2, 3, 4, 5, 5}, {{2}, {4}, {2}, {6}, {4}}}, {1, 1, 1, 1, 
       1}}]]]]],
  CellChangeTimes->{3.7987435487361455`*^9},ExpressionUUID->
  "ee617e13-629b-44ed-afc1-dd75af25f8ea"],
 "    y la inversa de  [Ady]\[Transpose] - [ I ]  es:  ",
 Cell[BoxData[
  TagBox[
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}]},
      {"0", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}]},
      {"0", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}]},
      {"0", "0", "0", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{"-", "1"}]},
      {"0", "0", "0", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}]},
      {"0", "0", "0", "0", "0", 
       RowBox[{"-", "1"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
   Function[BoxForm`e$, 
    MatrixForm[BoxForm`e$]]]],
  CellChangeTimes->{{3.798743658207263*^9, 3.798743686679406*^9}},
  ExpressionUUID->"d6576f03-1d2f-4364-a598-29938074f249"],
 ".  Al multiplicar esta matriz por el vector de valores de oferta menos \
demanda se obtiene el vector [Ab]."
}], "Text",ExpressionUUID->"c657ee59-c975-4306-b80f-3ce97fa05ae1"],

Cell[TextData[{
 "\n\n\n\n\nRealizado por Ricardo Mart\[IAcute]nez Lagunes para la Comisi\
\[OAcute]n Nacional del Agua   ",
 Cell[BoxData[
  GraphicsBox[
   TagBox[RasterBox[CompressedData["
1:eJzsvXdwHNeV/7sv/PH+fH+/eq/W61IkZZHWyqXfulze2me71t61f7uWZfEn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     "], {{0, 119}, {431, 0}}, {0, 255},
     ColorFunction->RGBColor],
    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
    Selectable->False],
   DefaultBaseStyle->"ImageGraphics",
   ImageSize->{197., Automatic},
   ImageSizeRaw->{431, 119},
   PlotRange->{{0, 431}, {0, 119}}]],ExpressionUUID->
  "38824da9-e535-4627-93c7-a9ca7d6e15ec"],
 "   D.R. 2020"
}], "Text",
 FontSize->12,ExpressionUUID->"36e38d05-f204-4c26-bbd2-ba0331337e76"]
}, Open  ]]
},
WindowSize->{1324, 709},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
Deployed->True,
CellContext->Notebook,
TrackCellChangeTimes->False,
FrontEndVersion->"11.3 para Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1488, 33, 117, 1, 34, "Text",ExpressionUUID->"c0710cb8-7450-4d85-9f80-4b7a92e7df30"],
Cell[CellGroupData[{
Cell[1630, 38, 124, 0, 96, "Title",ExpressionUUID->"4397d2aa-cd5f-4fae-8933-b446057acd75"],
Cell[1757, 40, 935, 16, 188, "Text",ExpressionUUID->"2f986ba0-073f-4e84-a480-c61c38fae621"],
Cell[CellGroupData[{
Cell[2717, 60, 15078, 369, 979, "Input",ExpressionUUID->"37fc8380-a03f-4982-ab8c-a96c66a4d3e1"],
Cell[17798, 431, 9473, 208, 573, "Output",ExpressionUUID->"1caa8ee1-8a5a-4e6f-90b8-ff4bc32a07fa"]
}, {2}]],
Cell[27283, 642, 2036, 41, 329, "Text",ExpressionUUID->"15699757-4761-48f6-8c20-b0660e9f25f7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29356, 688, 103, 0, 96, "Title",ExpressionUUID->"b58dab2d-66d0-4fec-8ee9-fdd7121b0244"],
Cell[29462, 690, 347, 5, 56, "Text",ExpressionUUID->"ac6b517c-1936-4614-a839-2116c6c60cce"],
Cell[CellGroupData[{
Cell[29834, 699, 2287, 57, 238, "Input",ExpressionUUID->"a07988e0-7b63-454e-8051-79d139e41ec8"],
Cell[32124, 758, 2832, 55, 403, "Output",ExpressionUUID->"c0c17efe-6f09-4f29-8391-666b7bc1aa42"]
}, {2}]],
Cell[34968, 816, 3436, 98, 153, "Text",ExpressionUUID->"94e9c821-ff36-45fc-a30b-7fb021310699"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38441, 919, 111, 0, 96, "Title",ExpressionUUID->"f654fa73-153b-44be-bdcd-62c4acdeca4d"],
Cell[38555, 921, 283, 4, 34, "Text",ExpressionUUID->"6b80a2b1-8ea5-477f-8a29-2ee38cc67682"],
Cell[CellGroupData[{
Cell[38863, 929, 8245, 201, 599, "Input",ExpressionUUID->"6f0035d2-bf34-4268-861e-7142f0a5133b"],
Cell[47111, 1132, 7710, 138, 635, "Output",ExpressionUUID->"9cf49882-6678-49c9-9992-5bed5172f2e1"]
}, {2}]],
Cell[54833, 1273, 2628, 74, 147, "Text",ExpressionUUID->"c657ee59-c975-4306-b80f-3ce97fa05ae1"],
Cell[57464, 1349, 49632, 820, 159, "Text",ExpressionUUID->"36e38d05-f204-4c26-bbd2-ba0331337e76"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Rx0j2NkZjXP1cC1Rsa9nnA62 *)
